pub struct RoleContribution {
pub role: String,
pub beta_to_team: f64,
pub mean_return: f64,
}Expand description
One role’s contribution to a team.
Fields
role: Stringbeta_to_team: f64Regression beta of the team return on this role — how much the team moves per unit of this role’s signal. Near 0 ⇒ the role isn’t load-bearing.
mean_return: f64Trait Implementations
Sourceimpl Clone for RoleContribution
impl Clone for RoleContribution
Sourcefn clone(&self) -> RoleContribution
fn clone(&self) -> RoleContribution
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RoleContribution
impl Debug for RoleContribution
Sourceimpl<'de> Deserialize<'de> for RoleContribution
impl<'de> Deserialize<'de> for RoleContribution
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for RoleContribution
impl PartialEq for RoleContribution
Sourceimpl Serialize for RoleContribution
impl Serialize for RoleContribution
impl StructuralPartialEq for RoleContribution